unit Main;

interface

uses
{$IFDEF WIN32}
  Windows,
{$ELSE}
  WinTypes, WinProcs,
{$ENDIF}
  Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, Compress, Segment;

type
  TMainForm = class(TForm)
    SegCompEZ: TSegCompEZ;
    TheLabel: TLabel;
    EFile: TEdit;
    CompBtn: TBitBtn;
    ScanBtn: TBitBtn;
    ExpandBtn: TBitBtn;
    ResetBtn: TBitBtn;
    LB: TListBox;
    Label1: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure CompBtnClick(Sender: TObject);
    procedure ResetBtnClick(Sender: TObject);
    procedure ScanBtnClick(Sender: TObject);
    procedure LBDblClick(Sender: TObject);
    procedure ExpandBtnClick(Sender: TObject);
    procedure SegCompEZSegBeforeExpand(var SegArcList: TSegArcList);
    procedure DoCheckFile(var filepath: OpenString; mode: TCProcessMode);
  private
    { Private declarations }
    procedure EnableButtons( const State: Boolean );
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

uses FileView, Alter;

{$R *.DFM}
const
   CR = #10#13;

procedure TMainForm.FormCreate(Sender: TObject);
begin
     EFile.Clear;
     LB.Clear;
end;

procedure TMainForm.FormShow(Sender: TObject);
begin
     ResetBtnClick(Sender);
end;

procedure TMainForm.CompBtnClick(Sender: TObject);
begin
     if (EFile.Text = '') then
       ShowMessage('You must enter a filename or template')
     else
       begin
       EnableButtons(False);
       with SegCompEZ do
         begin
         TargetPath := '';
         SegSource.Add(EFile.Text);
         try
           Compress;
         except
           ShowMessage('Compress failed');
         end;
         ResetBtn.Enabled := True;
         end;
       end;
end;

procedure TMainForm.ScanBtnClick(Sender: TObject);
var
   i:     Integer;
begin
     EFile.Clear;
     LB.Clear;
     EnableButtons(False);
     with SegCompEZ do
       begin
       SegSource.Clear;
       try
         Scan;
       except
         ShowMessage('Scan Failed');
       end;
       for i := 0 to SegSource.Count-1 do
         LB.Items.Add(SegSource[i]);
       LB.OnDblClick := LBDblClick;
       ShowMessage('Double click on any template in the Results window' + CR +
                   'to see the files in the archive.');
       ResetBtn.Enabled := True;
       end;
end;

procedure TMainForm.ExpandBtnClick(Sender: TObject);
begin
     EFile.Clear;
     LB.Clear;
     EnableButtons(False);
     with SegCompEZ do
       begin
       SegSource.Clear;
       try
         Expand;
       except
         ShowMessage('Expand Failed');
       end;
       ResetBtn.Enabled := True;
       end;
end;

procedure TMainForm.ResetBtnClick(Sender: TObject);
begin
     EFile.Clear;
     LB.Clear;
     SegCompEZ.SegSource.Clear;
     SegCompEZ.SegArcList.RemoveAll;
     EnableButtons(True);
     LB.OnDblClick := nil;
     EFile.SetFocus;
end;

procedure TMainForm.EnableButtons( const State: Boolean );
begin
     CompBtn.Enabled := State;
     ScanBtn.Enabled := State;
     ExpandBtn.Enabled := State;
     ResetBtn.Enabled := State;
end;

procedure TMainForm.LBDblClick(Sender: TObject);
var
   SArc:    TSegArc;
begin
     SArc := SegCompEZ.GetSegArc(LB.ItemIndex);
     FileForm.ShowFiles(SArc);
end;

procedure TMainForm.SegCompEZSegBeforeExpand(var SegArcList: TSegArcList);
var
   SArc:     TSegArc;
begin
     if (MessageDlg('Would you like to expand to an alternate location?',
          mtConfirmation,[mbYes,mbNo],0) = mrYes) then
       begin
         SArc := SegCompEZ.GetSegArc(0);   { There is only one in the demo }
         AltForm.NewTarget(SArc);
       end;
end;

procedure TMainForm.DoCheckFile(var filepath: OpenString;
  mode: TCProcessMode);
begin
     LB.Items.Add(filepath);
     LB.ItemIndex := LB.Items.Count-1;
end;

end.
