unit Selfiles;

interface

uses
{$IFDEF WIN32}
  Windows,
{$ELSE}
  WinTypes, WinProcs,
{$ENDIF}
  Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, FileCtrl, Compress, Segment;

type
  TSelFilesForm = class(TForm)
    DCB: TDriveComboBox;
    DLB: TDirectoryListBox;
    FLB: TFileListBox;
    CloseBtn: TBitBtn;
    LBGroup: TGroupBox;
    LB: TListBox;
    FileCnt: TLabel;
    SelBtn: TBitBtn;
    EFilter: TEdit;
    SelAllBtn: TBitBtn;
    ERecurse: TCheckBox;
    RestBtn: TBitBtn;
    procedure CloseBtnClick(Sender: TObject);
    procedure EFilterExit(Sender: TObject);
    procedure SelBtnClick(Sender: TObject);
    procedure LBKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure SelAllBtnClick(Sender: TObject);
    procedure FLBDblClick(Sender: TObject);
    procedure DCBChange(Sender: TObject);
    procedure DoKeyPress(Sender: TObject; var Key: Char);
    procedure DLBDblClick(Sender: TObject);
    procedure ERecurseClick(Sender: TObject);
    procedure RestBtnClick(Sender: TObject);
    procedure FLBClick(Sender: TObject);
  private
    { Private declarations }
    procedure SetLBCount;
    procedure UpdateLB;
  public
    { Public declarations }
    procedure SelectFiles( var Target: String; var SL: TStringList );
  end;

var
  SelFilesForm: TSelFilesForm;

implementation

uses Main, Common;

{$R *.DFM}

var
  TLB:         TStringList;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.SelectFiles( var Target: String; var SL: TStringList );
var
  CurDir:        String;
  i:             Integer;
begin
     TLB := TStringList.Create;
     SL.Clear;
     LB.Clear;
     SetLBCount;
     GetDir(0,CurDir);
     DLB.Directory := CurDir;
     EFilter.Text := FLB.Mask;
     if (MainForm.SegCompEZ.SegBuildMode = bmFlat) then
       ERecurse.State := cbUnChecked
     else
       ERecurse.State := cbChecked;
     FTarget := MakeTarget(LowerCase(FLB.Directory));
     LBGroup.Caption := FTarget;
     FLB.OnDblClick := FLBDblClick;
     FLB.ItemIndex := -1;
     Target := '';
     ShowModal;
     if (LB.Items.Count > 0) then
       begin
       for i := 0 to LB.Items.Count-1 do
         SL.Add(LB.Items[i]);
       Target := FTarget;
       end;
     TLB.Free;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.SelBtnClick(Sender: TObject);
var
   i:     Integer;
   SL:    TStringList;
begin
     if (FLB.SelCount = 0) then
       begin
       LB.Clear;
       TLB.Clear;
       SetLBCount;
       SL := TStringList.Create;
       InitFileList( MakeTarget(FLB.Directory)+EFilter.Text,
                     MainForm.SegCompEZ.SegBuildMode, SL );
       for i := 0 to SL.Count-1 do
         AddUniqueFile(TLB,SL[i]);
       SL.Free;
       end
     else
       begin
       for i := 0 to FLB.Items.Count-1 do
         begin
         if (FLB.Selected[i]) then
           AddUniqueFile(TLB,MakeTarget(FLB.Directory) + FLB.Items[i]);
         end;
       end;

     UpdateLB;
     LBGroup.Caption := FTarget;
     SetLBCount;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.SelAllBtnClick(Sender: TObject);
var
   i:     Integer;
   SL:    TStringList;
begin
     SL := TStringList.Create;
     InitFileList( MakeTarget(FLB.Directory)+EFilter.Text,
                   MainForm.SegCompEZ.SegBuildMode, SL );
     for i := 0 to SL.Count-1 do
       AddUniqueFile(TLB,SL[i]);
     SL.Free;
     UpdateLB;
     LBGroup.Caption := FTarget;
     SetLBCount;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.FLBClick(Sender: TObject);
begin
     if (FLB.SelCount > 0) then
       SelBtn.Enabled := True;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.FLBDblClick(Sender: TObject);
begin
     SelBtn.Enabled := True;
     AddUniqueFile(TLB,MakeTarget(FLB.Directory) + FLB.Items[FLB.ItemIndex]);
     UpdateLB;
     LBGroup.Caption := FTarget;
     SetLBCount;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.DLBDblClick(Sender: TObject);
begin
     FTarget := MakeTarget(LowerCase(FLB.Directory));
     LBGroup.Caption := FTarget;
     if ((FLB.Items.Count = 0) or (FLB.SelCount = 0)) then
       SelBtn.Enabled := False
     else
       SelBtn.Enabled := True;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.DCBChange(Sender: TObject);
begin
     FTarget := MakeTarget(LowerCase(FLB.Directory));
     LB.Clear;
     TLB.Clear;
     LBGroup.Caption := FTarget;
     SetLBCount;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.ERecurseClick(Sender: TObject);
begin
     if (ERecurse.State = cbChecked) then
       MainForm.SegCompEZ.SegBuildMode := bmRecursive
     else
       MainForm.SegCompEZ.SegBuildMode := bmFlat;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.RestBtnClick(Sender: TObject);
var
   i:    Integer;
begin
     FTarget := MakeTarget(LowerCase(FLB.Directory));
     LB.Clear;
     TLB.Clear;
     LBGroup.Caption := FTarget;
     for i := 0 to FLB.Items.Count-1 do
       FLB.Selected[i] := False;
     FLB.ItemIndex := -1;
     SelBtn.Enabled := False;
     SetLBCount;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.CloseBtnClick(Sender: TObject);
begin
     Close;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.UpdateLB;
var
   i:      Integer;
begin
     if (TLB.COunt > 0) then
       FTarget := CommonTarget(TLB);
     LB.Clear;
     for i := 0 to TLB.Count-1 do
       LB.Items.Add(Copy(TLB[i],Length(FTarget)+1,Length(TLB[i])-Length(FTarget)));
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.SetLBCount;
begin
     FileCnt.Caption := 'Count: ' + IntToStr(LB.Items.Count);
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.EFilterExit(Sender: TObject);
begin
     if (EFilter.Text = '') then
       EFilter.Text := FLB.Mask;
     FLB.Mask := EFilter.Text;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.LBKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var
   i:      Integer;
begin
     if (Key = VK_DELETE) then
       begin
       while (LB.SelCount > 0) do
         begin
         for i := 0 to LB.Items.Count-1 do
           begin
           if (LB.Selected[i]) then
             begin
             LB.Items.Delete(i);
             TLB.Delete(i);
             SetLBCount;
             break;
             end;
           end;
         end;

       if (LB.Items.Count > 0) then
         begin
         FTarget := CommonTarget(TLB);
         LBGroup.Caption := FTarget;
         end;
       end;
end;

{===============================================================}
{===============================================================}
procedure TSelFilesForm.DoKeyPress(Sender: TObject; var Key: Char);
begin
     if (Key = #13) then
       begin
       SelectNext(Sender as tWinControl,True,True);
       Key := #0;
       end;
end;

end.
